ExpLeak
-------
Exponential Leaky layer which acts as a lowpass filter.

.. currentmodule:: sinabs.layers

.. autoclass:: ExpLeak
    :members:

ExpLeakSqueeze
--------------
.. autoclass:: ExpLeakSqueeze
    :members:
